@@ -149,7 +149,7 @@ impl Loader for FetchCacher {
     let file_fetcher = self.file_fetcher.clone();
 
     async move {
-      let load_result = file_fetcher
+      file_fetcher
         .fetch(&specifier, &mut permissions)
         .await
         .map_or_else(
@@ -170,9 +170,7 @@ impl Loader for FetchCacher {
               content: file.source,
             }))
           },
-        );
-
-      (specifier, load_result)
+        )
     }
     .boxed()
   }
@@ -295,7 +293,7 @@ impl Loader for MemoryCacher {
       maybe_headers: None,
       content: c.to_owned(),
     });
-    Box::pin(future::ready((specifier.clone(), Ok(response))))
+    Box::pin(future::ready(Ok(response)))
   }
 }
 
