@@ -157,7 +157,7 @@ impl DenoTestCollector {
 
 impl Visit for DenoTestCollector {
   fn visit_call_expr(&mut self, node: &ast::CallExpr) {
-    if let ast::ExprOrSuper::Expr(callee_expr) = &node.callee {
+    if let ast::Callee::Expr(callee_expr) = &node.callee {
       match callee_expr.as_ref() {
         ast::Expr::Ident(ident) => {
           if self.test_vars.contains(&ident.sym.to_string()) {
@@ -165,13 +165,11 @@ impl Visit for DenoTestCollector {
           }
         }
         ast::Expr::Member(member_expr) => {
-          if let ast::Expr::Ident(ns_prop_ident) = member_expr.prop.as_ref() {
+          if let ast::MemberProp::Ident(ns_prop_ident) = &member_expr.prop {
             if ns_prop_ident.sym.to_string() == "test" {
-              if let ast::ExprOrSuper::Expr(obj_expr) = &member_expr.obj {
-                if let ast::Expr::Ident(ident) = obj_expr.as_ref() {
-                  if ident.sym.to_string() == "Deno" {
-                    self.check_call_expr(node, &ns_prop_ident.span);
-                  }
+              if let ast::Expr::Ident(ident) = member_expr.obj.as_ref() {
+                if ident.sym.to_string() == "Deno" {
+                  self.check_call_expr(node, &ns_prop_ident.span);
                 }
               }
             }
@@ -219,16 +217,12 @@ impl Visit for DenoTestCollector {
           }
           // Identify variable assignments where the init is `Deno.test`
           ast::Expr::Member(member_expr) => {
-            if let ast::ExprOrSuper::Expr(expr) = &member_expr.obj {
-              if let ast::Expr::Ident(obj_ident) = expr.as_ref() {
-                if obj_ident.sym.to_string() == "Deno" {
-                  if let ast::Expr::Ident(prop_ident) =
-                    &member_expr.prop.as_ref()
-                  {
-                    if prop_ident.sym.to_string() == "test" {
-                      if let ast::Pat::Ident(binding_ident) = &decl.name {
-                        self.test_vars.insert(binding_ident.id.sym.to_string());
-                      }
+            if let ast::Expr::Ident(obj_ident) = member_expr.obj.as_ref() {
+              if obj_ident.sym.to_string() == "Deno" {
+                if let ast::MemberProp::Ident(prop_ident) = &member_expr.prop {
+                  if prop_ident.sym.to_string() == "test" {
+                    if let ast::Pat::Ident(binding_ident) = &decl.name {
+                      self.test_vars.insert(binding_ident.id.sym.to_string());
                     }
                   }
                 }
@@ -245,7 +239,7 @@ impl Visit for DenoTestCollector {
 async fn resolve_implementation_code_lens(
   code_lens: lsp::CodeLens,
   data: CodeLensData,
-  language_server: &mut language_server::Inner,
+  language_server: &language_server::Inner,
 ) -> Result<lsp::CodeLens, AnyError> {
   let asset_or_doc =
     language_server.get_cached_asset_or_document(&data.specifier)?;
@@ -254,7 +248,7 @@ async fn resolve_implementation_code_lens(
     data.specifier.clone(),
     line_index.offset_tsc(code_lens.range.start)?,
   ));
-  let snapshot = language_server.snapshot()?;
+  let snapshot = language_server.snapshot();
   let maybe_implementations: Option<Vec<tsc::ImplementationLocation>> =
     language_server.ts_server.request(snapshot, req).await?;
   if let Some(implementations) = maybe_implementations {
@@ -314,7 +308,7 @@ async fn resolve_implementation_code_lens(
 async fn resolve_references_code_lens(
   code_lens: lsp::CodeLens,
   data: CodeLensData,
-  language_server: &mut language_server::Inner,
+  language_server: &language_server::Inner,
 ) -> Result<lsp::CodeLens, AnyError> {
   let asset_or_document =
     language_server.get_cached_asset_or_document(&data.specifier)?;
@@ -323,7 +317,7 @@ async fn resolve_references_code_lens(
     data.specifier.clone(),
     line_index.offset_tsc(code_lens.range.start)?,
   ));
-  let snapshot = language_server.snapshot()?;
+  let snapshot = language_server.snapshot();
   let maybe_references: Option<Vec<tsc::ReferenceEntry>> =
     language_server.ts_server.request(snapshot, req).await?;
   if let Some(references) = maybe_references {
@@ -338,7 +332,8 @@ async fn resolve_references_code_lens(
         .get_asset_or_document(&reference_specifier)
         .await?;
       locations.push(
-        reference.to_location(asset_or_doc.line_index(), language_server),
+        reference
+          .to_location(asset_or_doc.line_index(), &language_server.url_map),
       );
     }
     let command = if !locations.is_empty() {
@@ -384,7 +379,7 @@ async fn resolve_references_code_lens(
 
 pub(crate) async fn resolve_code_lens(
   code_lens: lsp::CodeLens,
-  language_server: &mut language_server::Inner,
+  language_server: &language_server::Inner,
 ) -> Result<lsp::CodeLens, AnyError> {
   let data: CodeLensData =
     serde_json::from_value(code_lens.data.clone().unwrap())?;
