@@ -1,8 +1,8 @@
 // Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
-mod ast;
 mod auth_tokens;
 mod cache;
+mod cdp;
 mod checksum;
 mod compat;
 mod config_file;
@@ -475,6 +475,7 @@ async fn info_command(
       maybe_resolver,
       maybe_locker,
       None,
+      None,
     )
     .await;
 
@@ -654,6 +655,7 @@ async fn create_graph_and_maybe_check(
       maybe_resolver,
       maybe_locker,
       None,
+      None,
     )
     .await,
   );
@@ -732,6 +734,7 @@ fn bundle_module_graph(
     emit::BundleOptions {
       bundle_type: emit::BundleType::Module,
       ts_config,
+      emit_ignore_directives: true,
     },
   )
 }
@@ -909,6 +912,8 @@ async fn repl_command(
   if flags.compat {
     worker.execute_side_module(&compat::GLOBAL_URL).await?;
     compat::add_global_require(&mut worker.js_runtime, main_module.as_str())?;
+    worker.run_event_loop(false).await?;
+    compat::setup_builtin_modules(&mut worker.js_runtime)?;
   }
   worker.run_event_loop(false).await?;
 
@@ -996,6 +1001,7 @@ async fn run_with_watch(flags: Flags, script: String) -> Result<i32, AnyError> {
         maybe_resolver,
         maybe_locker,
         None,
+        None,
       )
       .await;
       let check_js = ps
@@ -1181,6 +1187,7 @@ async fn run_command(
       compat::load_cjs_module(
         &mut worker.js_runtime,
         &main_module.to_file_path().unwrap().display().to_string(),
+        true,
       )?;
     }
   } else {
@@ -1370,7 +1377,11 @@ fn unwrap_or_exit<T>(result: Result<T, AnyError>) -> T {
   match result {
     Ok(value) => value,
     Err(error) => {
-      eprintln!("{}: {:?}", colors::red_bold("error"), error);
+      eprintln!(
+        "{}: {}",
+        colors::red_bold("error"),
+        format!("{:?}", error).trim_start_matches("error: ")
+      );
       std::process::exit(1);
     }
   }
@@ -1398,11 +1409,10 @@ pub fn main() {
   let flags = match flags::flags_from_vec(args) {
     Ok(flags) => flags,
     Err(err @ clap::Error { .. })
-      if err.kind == clap::ErrorKind::HelpDisplayed
-        || err.kind == clap::ErrorKind::VersionDisplayed =>
+      if err.kind == clap::ErrorKind::DisplayHelp
+        || err.kind == clap::ErrorKind::DisplayVersion =>
     {
-      err.write_to(&mut std::io::stdout()).unwrap();
-      std::io::stdout().write_all(b"\n").unwrap();
+      err.print().unwrap();
       std::process::exit(0);
     }
     Err(err) => unwrap_or_exit(Err(AnyError::from(err))),
