@@ -51,11 +51,25 @@ pub static SHARED_GLOBALS_LIB: &str =
 pub static WINDOW_LIB: &str = include_str!("dts/lib.deno.window.d.ts");
 pub static UNSTABLE_NS_LIB: &str = include_str!("dts/lib.deno.unstable.d.ts");
 
-pub static COMPILER_SNAPSHOT: &[u8] =
-  include_bytes!(concat!(env!("OUT_DIR"), "/COMPILER_SNAPSHOT.bin"));
+pub static COMPILER_SNAPSHOT: Lazy<Box<[u8]>> = Lazy::new(
+  #[cold]
+  #[inline(never)]
+  || {
+    static COMPRESSED_COMPILER_SNAPSHOT: &[u8] =
+      include_bytes!(concat!(env!("OUT_DIR"), "/COMPILER_SNAPSHOT.bin"));
+
+    zstd::block::decompress(
+      &COMPRESSED_COMPILER_SNAPSHOT[4..],
+      u32::from_le_bytes(COMPRESSED_COMPILER_SNAPSHOT[0..4].try_into().unwrap())
+        as usize,
+    )
+    .unwrap()
+    .into_boxed_slice()
+  },
+);
 
 pub fn compiler_snapshot() -> Snapshot {
-  Snapshot::Static(COMPILER_SNAPSHOT)
+  Snapshot::Static(&*COMPILER_SNAPSHOT)
 }
 
 macro_rules! inc {
@@ -675,7 +689,7 @@ mod tests {
           })
         })
         .map_err(|err| err.into());
-      Box::pin(future::ready((specifier.clone(), response)))
+      Box::pin(future::ready(response))
     }
   }
 
@@ -697,6 +711,7 @@ mod tests {
       None,
       None,
       None,
+      None,
     )
     .await;
     State::new(
@@ -723,6 +738,7 @@ mod tests {
       None,
       None,
       None,
+      None,
     )
     .await;
     let config = TsConfig::new(json!({
